def main():
    print("Welcome to CrappyText! This is the world's crappiest text editor.")

if __name__ == "__main__":
    main()
else:
    raise RuntimeError("CrappyText is not meant to be imported, try running it as a script.")